clear
set mem 700m
set matsize 800
set more off

*******************************************************************************************
************CCAP VALIDATED TURNOUT ANALYSIS************************************************
*******************************************************************************************
use ccap_validated.dta, clear

** TOTAL TURNOUT
qui forvalues i=2000(2)2006{
 gen turn`i'=vh_g`i'
 replace turn`i'=0 if vh_g`i'!=1
}
gen turntotal=turn2000+turn2002+turn2004+turn2006
label var turntotal "All Elections"

*** CODE VARIABLES
****************************
***DEMOGRAPHIC VARIABLES****
****************************
** Generate State indicators; Drop indicator for CA (dominant category [weighted])
quietly tab profile66, gen(stateC_)
drop stateC_5

* female
recode profile54 (1=0) (2=1) (*=.), gen(female)
label var female "Female = 1"

* Race, no missing
gen r_white =(profile55==1)
gen r_black = (profile55==2)
gen r_hispanic = (profile55==3)
gen r_other = (profile55==4 | profile55==5 | profile55==6 | profile55==7 | profile55==8)
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
label var r_other "Other (Native American,Asian,Mixed,Other) = 1"

* Education, drop missing
gen educ=profile57 
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 2 (HS Diploma)
drop educC_2
label var educC_1 "Educ<HS"
label var educC_3 "Educ=some college"
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

* Family Income
* Skipped/RF set to missing, plus indicator for missing
gen income=profile59
gen incomemis = (income>=15)
replace income=15 if incomemis==1
replace income=(income-1)/14
label var incomemis "Income Refused"
label var income "Income (0-1, 1=Refused)"

* Age and Age2
gen birthyr=profile51
label var birthyr "birth year"
gen age=2008-birthyr 
label var age "Age (Years)"
gen age2=(age^2)/100
label var age2 "Age^2/100"

****************************
**CONSTRUCT BIG FIVE ITEMS**
****************************
*personality - extraverted
gen b_p_extraverted=profile40
*personality - critical 
gen b_p_critical=profile41 
*personality - dependable
gen b_p_dependable=profile42 
*personality - anxious
gen b_p_anxious=profile43 
*personality - open to new experiences
gen b_p_open=profile44 
*personality - reserved
gen b_p_reserved=profile45 
*personality - sympathetic
gen b_p_sympathetic=profile46 
*personality - disorganized
gen b_p_disorganized=profile47 
*personality - calm
gen b_p_calm=profile48 
*personality - conventional
gen b_p_conventional=profile49 

**set missing
recode b_p_extraverted b_p_critical b_p_dependable b_p_anxious b_p_open b_p_reserved b_p_sympathetic b_p_disorganized b_p_calm b_p_conventional (8=.) (9=.)

**reverse code as needed
recode b_p_reserved b_p_critical b_p_disorganized b_p_anxious b_p_conventional (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_reserved_R b_p_critical_R b_p_disorganized_R b_p_anxious_R b_p_conventional_R)

*Items range from 0 to 1 -- higher values mean more of the trait
*Big Five - extraversion
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*Big Five - agreeableness
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - conscientiousness
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - emotional stability
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Stability (0-1)"

*Big Five - openness to experiences
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
gen BF_openness_alt = (b_p_open-1)/6
label var BF_openness "Openness (0-1)"
label var BF_openness_alt "Openness (0-1) [no conventional item]"

**Restrict sample to individuals eligible to vote in 2000
gen insample=1
replace insample=0 if age<26

**Restrict analysis to states where there is variation in turnout.
levelsof profile66, local(levels)
qui foreach state of local levels {
 summ turntotal if profile66==`state'
 replace insample=0 if r(sd)==0 & profile66==`state'
}

*Exclude MA because old voter file used (i.e., no turnout data for 2002-2006).
replace insample=0 if profile66==25

ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 state* if insample==1 [pw=psweight], cluster(profile66)
replace insample=0 if e(sample)==0

*** SUMMARY STATISTICS
outsum BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age income incomemis educ [aw=psweight] if insample==1 using "tableA1_summarystats.out", bracket ctitle(CCAP Valid) replace 

*** CORRELATIONS BETWEEN BIG FIVE
corr BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness if insample==1 [aw=psweight]

*TURNOUT 
**** NO EDUCATION/INCOME MODEL
ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
local a=r(p)
sum turntotal if insample==1 [aw=psweight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "table3_validTO_noeducinc.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster replace

**** COUNT MODEL
nbreg turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
local a=r(p)
sum turntotal if insample==1 [aw=psweight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "table3_validTO_countmodels.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster replace

**** ALT OPENNESS MODEL
ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
local a=r(p)
sum turntotal if insample==1 [aw=psweight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* using "table3_validTO_alt.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster replace

**** REPORTED MODEL
ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* if insample==1 [pw=psweight], cluster(profile66)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
local a=r(p)
sum turntotal if insample==1 [aw=psweight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "table3_validTO.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster replace

*This is the marginal effects for the income/education specification
*Outcome is turntotal being 3 or 4
qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
 if "`varofinterest'"~="income" {
  summ `varofinterest' if e(sample) [aweight=psweight]
 }
 else {
  *varofinterest=1 is to exclude income missing folks
  summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=psweight]
 }
 local sd2=`r(sd)'*2
 prchange `varofinterest', x(age=51 age2=26.01  income=.53 female==1 BF_extraversion=.51 BF_agreeableness=.73 BF_conscientiousness=.77 BF_stability=.69 BF_openness=.71) rest(min) fromto delta(`sd2')
 matrix base=r(predval)
 matrix base1=base[1,4]
 matrix base2=base[1,5]
 matrix base=base1+base2
 if "`varofinterest'"~="educC_5" {
  matrix mfx=r(change3)
  matrix submfx1=mfx[9,1]
  matrix mfx=r(change4)
  matrix submfx2=mfx[9,1]
 }
 else {
  matrix mfx=r(change3)
  matrix submfx1=mfx[6,1]
  matrix mfx=r(change4)
  matrix submfx2=mfx[6,1]
 }
 matrix submfx=submfx1+submfx2
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx=base
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
  else {
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
}

matrix list finalmfx
matrix valid_turnoutmfx=finalmfx

svmat valid_turnoutmfx, names(turnoutmfx)
outsheet turnoutmfx* using table3B_validTO_mfx_1.csv,comma replace
drop turnoutmfx* 

foreach v in turn2000 turn2002 turn2004 turn2006 {
*** ALT OPENNESS MODEL 
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* state* if insample==1 [pw=psweight], cluster(profile66)
 sum `v' if insample==1 [aw=psweight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
 if "`v'"=="turn2000" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* using "byelection_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* using "byelection_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }
*** REPORTED MODEL 
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* if insample==1 [pw=psweight], cluster(profile66)
 sum `v' if insample==1 [aw=psweight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 if "`v'"=="turn2000" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "byelection.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "byelection.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }

 *MFX for each variable here is probability of being in category 1
 *This is the marginal effects for the income/education specification
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* if e(sample)==1 [pw=psweight], cluster(profile66)
 qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
  if "`varofinterest'"~="income" {
   summ `varofinterest' if e(sample) [aweight=psweight]
  }
  else {
   *varofinterest=1 is to exclude income missing folks
   summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=psweight]
  }
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(age=51 age2=26.01  income=.53 female==1 BF_extraversion=.51 BF_agreeableness=.73 BF_conscientiousness=.77 BF_stability=.69 BF_openness=.71) rest(min) fromto delta(`sd2')
  matrix base=r(predval)
  matrix base=base[1,2]
  matrix mfx=r(change)
  if "`varofinterest'"~="educC_5" {
   matrix submfx=mfx[9,1]
  }
  else {
   matrix submfx=mfx[6,1]
  }
  if "`varofinterest'"=="BF_extraversion" {
   matrix finalmfx=base
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
   else {
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
  }
 matrix list finalmfx
 if "`v'"=="turn2000" {
 matrix by_election_mfx=finalmfx
 }
 else{
 matrix by_election_mfx=by_election_mfx,finalmfx
 }
}
svmat by_election_mfx, names(turnoutmfx)
outsheet turnoutmfx* using by_election_mfx1.csv,comma replace
drop turnoutmfx* 

*******************************************************************************************
************CCAP OTHER PARTICIPATION ANALYSIS**********************************************
*******************************************************************************************
use ccap_common.dta, clear

*** CODE VARIABLES
****************************
***DEMOGRAPHIC VARIABLES****
****************************
** Generate State indicators; Drop indicator for CA (dominant category [weighted])
quietly tab profile66, gen(stateC_)
drop stateC_5

* female
recode profile54 (1=0) (2=1) (*=.), gen(female)
label var female "Female = 1"

* Race, no missing
gen r_white =(profile55==1)
gen r_black = (profile55==2)
gen r_hispanic = (profile55==3)
gen r_other = (profile55==4 | profile55==5 | profile55==6 | profile55==7 | profile55==8)
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
label var r_other "Other (Native American,Asian,Mixed,Other) = 1"

* Education, drop missing
gen educ=profile57 
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 2 (HS Diploma)
drop educC_2
label var educC_1 "Educ<HS"
label var educC_3 "Educ=some college"
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

* Family Income
* Skipped/RF set to missing, plus indicator for missing
gen income=profile59
gen incomemis = (income>=15)
replace income=15 if incomemis==1
replace income=(income-1)/14
label var incomemis "Income Refused"
label var income "Income (0-1, 1=Refused)"

* Age and Age2
gen birthyr=profile51
label var birthyr "birth year"
gen age=2008-birthyr 
label var age "Age (Years)"
gen age2=(age^2)/100
label var age2 "Age^2/100"

****************************
**CONSTRUCT BIG FIVE ITEMS**
****************************
*personality - extraverted
gen b_p_extraverted=profile40
*personality - critical 
gen b_p_critical=profile41 
*personality - dependable
gen b_p_dependable=profile42 
*personality - anxious
gen b_p_anxious=profile43 
*personality - open to new experiences
gen b_p_open=profile44 
*personality - reserved
gen b_p_reserved=profile45 
*personality - sympathetic
gen b_p_sympathetic=profile46 
*personality - disorganized
gen b_p_disorganized=profile47 
*personality - calm
gen b_p_calm=profile48 
*personality - conventional
gen b_p_conventional=profile49 

**set missing
recode b_p_extraverted b_p_critical b_p_dependable b_p_anxious b_p_open b_p_reserved b_p_sympathetic b_p_disorganized b_p_calm b_p_conventional (8=.) (9=.)

**reverse code as needed
recode b_p_reserved b_p_critical b_p_disorganized b_p_anxious b_p_conventional (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(b_p_reserved_R b_p_critical_R b_p_disorganized_R b_p_anxious_R b_p_conventional_R)

*Items range from 0 to 1 -- higher values mean more of the trait
*Big Five - extraversion
gen BF_extraversion = (((b_p_extraverted + b_p_reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*Big Five - agreeableness
gen BF_agreeableness = (((b_p_sympathetic + b_p_critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - conscientiousness
gen BF_conscientiousness = (((b_p_dependable + b_p_disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - emotional stability
gen BF_stability = (((b_p_calm + b_p_anxious_R)/2)-1)/6
label var BF_stability "Stability (0-1)"

*Big Five - openness to experiences
gen BF_openness = (((b_p_open + b_p_conventional_R)/2)-1)/6
gen BF_openness_alt = (b_p_open-1)/6
label var BF_openness "Openness (0-1)"
label var BF_openness_alt "Openness (0-1) [no conventional item]"

* Other participation
recode *cap400_* (1=1) (2=0) (*=.)
qui foreach i in s o {
 if "`i'"=="s" {
  local month="(September)"
 }
 if "`i'"=="o" {
 local month="(October)"
 }
 gen `i'_pas_mail=`i'cap400_2
 gen `i'_pas_pamphlet=`i'cap400_4
 gen `i'_pas_visit=`i'cap400_7
 gen `i'_pas_mess=`i'cap400_11
 label var `i'_pas_mail "Passive: Mail `month'"
 label var `i'_pas_pamphlet "Passive: Pamphlet `month'"
 label var `i'_pas_visit "Passive: Visit `month'"
 label var `i'_pas_mess "Passive: Message/Phone `month'"

 gen `i'_act_donate=`i'cap400_3
 gen `i'_act_button=`i'cap400_5
 gen `i'_act_discuss=`i'cap400_6
 gen `i'_act_rally=`i'cap400_10
 gen `i'_act_website=`i'cap400_12
 label var `i'_act_donate "Active: Donated `month'"
 label var `i'_act_button "Active: Wore Button `month'"
 label var `i'_act_discuss "Active: Discussed `month'"
 label var `i'_act_rally "Active: Attended Rally `month'"
 label var `i'_act_website "Active: Visited Website `month'"
}

qui foreach p in act_donate act_button act_discuss act_rally act_website {
 gen sp_`p'=o_`p'+s_`p'
 replace sp_`p'=1 if sp_`p'==2
}

label var sp_act_donate "Active: Donated"
label var sp_act_button "Active: Wore Button"
label var sp_act_discuss "Active: Discussed"
label var sp_act_rally "Active: Attended Rally"
label var sp_act_website "Active: Visited Website"

gen sp_active=sp_act_donate+sp_act_button+sp_act_rally
label var sp_active "Campaign Participation Index (0-3)"

***DATE INDICATORS
gen septdate=dofC(profile73s)
gen s_day=dow(septdate)
gen octdate=dofC(profile73o)
gen o_day=dow(octdate)
qui tab s_day, gen(sDay)
drop sDay1
qui tab o_day, gen(oDay)
drop oDay1

* RESTRICT TO INDIVIDUALS ELIGIBLE TO VOTE IN 2000 (TO BE COMPARABLE ACROSS SAMPLES)
gen insample=1
replace insample=0 if age<26

** RESTRICT SAMPLE TO CASES WITH VARIATION IN ALL OUTCOMES
 foreach v in sp_act_donate sp_act_button sp_act_rally {
//  logit `v' female interest r_black r_hispanic r_other religatt religattmis age age2 income incomemis educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* sDay* oDay* 
  logit `v' female r_black r_hispanic r_other age age2 income incomemis educC_* BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness state* sDay* oDay* 
  replace insample=0 if e(sample)==0
 }

*** SUMMARY STATISTICS
outsum BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age income incomemis educ if insample==1 [aw=psweight] using "tableA1_summarystats", bracket ctitle(CCAP Common Content) append

*** CORRELATIONS BETWEEN BIG FIVE
corr BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness if insample==1 [aw=psweight]

*** PARTICIPATION INDICES
**** NO INCOME/EDUC
ologit sp_active BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 state* oDay* sDay* if insample==1 [pw=psweight], cluster(profile66)
sum sp_active if insample==1 [aw=psweight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 using "table4_report_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace 

**** COUNT MODEL
nbreg sp_active BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* oDay* sDay* if insample==1 [pw=psweight], cluster(profile66)
sum sp_active if insample==1 [aw=psweight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "table4_report_countmodels.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace

**** ALT OPENNESS MODEL
ologit sp_active BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* state* oDay* sDay* if insample==1 [pw=psweight], cluster(profile66)
sum sp_active if insample==1 [aw=psweight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* using "table4_report_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace

**** REPORTED MODEL
ologit sp_active BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* oDay* sDay* if insample==1 [pw=psweight], cluster(profile66)
sum sp_active if insample==1 [aw=psweight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "table4_report.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace

*This is the marginal effects for the income/education specification
*Outcome is sp_active not being 0
qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
 if "`varofinterest'"~="income" {
  summ `varofinterest' if e(sample) [aweight=psweight]
 }
 else {
  *varofinterest=1 is to exclude income missing folks
  summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=psweight]
 }
 local sd2=`r(sd)'*2
 prchange `varofinterest', x(age=49 age2=24.01 income=.50 female==1 BF_extraversion=.51 BF_agreeableness=.71 BF_conscientiousness=.76 BF_stability=.67 BF_openness=.70) rest(min) fromto delta(`sd2')
 matrix base=r(predval)
 matrix base=1-base[1,1]
 matrix mfx=r(change0)
 if "`varofinterest'"~="educC_5" {
  matrix submfx=-1*mfx[9,1]
 }
 else {
  matrix submfx=-1*mfx[6,1]
 }
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx=base
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
  else {
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
}

matrix list finalmfx
matrix active_mfx=finalmfx
svmat active_mfx, names(turnoutmfx)
outsheet turnoutmfx* using table4_report_mfx_1.csv,comma replace
drop turnoutmfx* 

***ACTIVE, individual items for appendix
foreach v in sp_act_donate sp_act_button sp_act_rally {
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* state* oDay* sDay* if insample==1 [pw=psweight], cluster(profile66)
 sum `v' if insample==1 [aw=psweight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 if "`v'"=="sp_act_donate" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "items_appendix.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness female r_black r_hispanic r_other age age2 income incomemis educC_* using "items_appendix.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }
*** ALT OPENNESS MODEL
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* state* oDay* sDay* if insample==1 [pw=psweight], cluster(profile66)
 sum `v' if insample==1 [aw=psweight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
 if "`v'"=="sp_act_donate" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* using "items_appendix_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt female r_black r_hispanic r_other age age2 income incomemis educC_* using "items_appendix_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }
}

*******************************************************************************************
************CONNECTICUT SURVEY ANALYSIS****************************************************
*******************************************************************************************
use ct_survey.dta, clear
****************************
**CONSTRUCT BIG FIVE ITEMS**
****************************
* replace non-response w/missing
foreach i of varlist r2a-r2j{
replace `i'=. if `i'==9
}

* rename variables
rename r2a extraverted
rename r2b critical
rename r2c dependable
rename r2d anxious
rename r2e open
rename r2f reserved
rename r2g sympathetic
rename r2h disorganized
rename r2i calm
rename r2j conventional

* reverse code as necessary
recode reserved critical disorganized anxious conventional (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), gen(reserved_R critical_R disorganized_R anxious_R conventional_R)

*Items range from 0 to 1 -- higher values mean more of the trait
*Big Five - extraversion
gen BF_extraversion = (((extraverted + reserved_R)/2)-1)/6
label var BF_extraversion "Extraversion (0-1)"

*Big Five - agreeableness
gen BF_agreeableness = (((sympathetic + critical_R)/2)-1)/6
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - conscientiousness
gen BF_conscientiousness = (((dependable + disorganized_R)/2)-1)/6
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - emotional stability
gen BF_stability = (((calm + anxious_R)/2)-1)/6
label var BF_stability "Stability (0-1)"

*Big Five - openness to experiences
gen BF_openness = (((open + conventional_R)/2)-1)/6
label var BF_openness "Openness (0-1)"
gen BF_openness_alt = (open-1)/6
label var BF_openness "Openness (0-1)"
label var BF_openness_alt "Openness (0-1) [no conventional item]"

*Educ
gen educ=r9
replace educ=. if educ>90 | educ==0
label var educ "Education (1=No HS; 6=Post-grad)"
tab educ, gen(educC_)
*drop category 2
drop educC_2
label var educC_1 "Educ<HS"
label var educC_3 "Educ=some college"
label var educC_4 "Educ=2 year college"
label var educC_5 "Educ=College"
label var educC_6 "Educ=Post Grad"

gen r_white=0
replace r_white=1 if r10==1
label var r_white "White = 1"

gen r_nwhite=abs(r_white-1)
label var r_nwhite "Non-White = 1"

gen r_black=0
replace r_black=1 if r10==2
label var r_black "Black = 1"

gen r_hispanic=0
replace r_hispanic=1 if r10==5
label var r_hispanic "Hispanic = 1"

*income
gen income=r29
replace income=7 if r29>6
replace income=(income-1)/6
gen incomemis=(income==1)
label var incomemis "Income Refused"
label var income "Income (0-1, 1=Refused)"

replace yearborn = . if yearborn==9997 | yearborn==9998 | yearborn==9999
gen birthyr=yearborn 
gen age=2008-birthyr 
label var age "Age (Years)"
gen age2=(age^2)/100
label var age2 "Age^2/100"

****OUTCOMES*****
recode r15 r16 r16b r17 r18 r19 r20 r21a r21b (1=0) (2=1) (*=.), gen(act_local_official act_local_meet act_local_meet_speak act_rally act_volunteer act_donate_gen act_donate_cand act_persuade act_research)
replace act_local_meet_speak=0 if act_local_meet==0
label var act_local_official "Active: Contact Local Official" 
label var act_local_meet "Active: Attend Local Meeting"
label var act_local_meet_speak "Active: Speak at Local Meeting"
label var act_rally "Active: Attended Rally"
label var act_volunteer "Active: Volunteer"
label var act_donate_gen "Active: Donate to Political Cause"
label var act_donate_cand "Active: Donate to Political Candidate"
label var act_persuade "Active: Try to Persuade"
label var act_research "Active: Research"

gen act_campaign=act_rally+act_volunteer+act_donate_cand
gen act_local=act_local_official+act_local_meet+act_local_meet_speak
label var act_campaign "Campaign Participation Index (0-3)"
label var act_local "Local Participation Index (0-3)"

*valid turnout
gen turntotal=v2000g+v2002g+v2004g+v2006g
gen turnrecent=v2004g+v2006g
label var turntotal "All Elections"
label var turnrecent "Turnout: 2004 and 2006(0-2)"

*report turnout
recode r11 r12 r13 (1=1) (5 8=0) (*=.), gen(repturn04 repturn06 repturn08p)
label var repturn04 "Reported Turnout 2004"
label var repturn06 "Reported Turnout 2006"
label var repturn08p "Reported Turnout 2008 Primary"
gen repturn_total=repturn04+repturn06
label var repturn_total "Reported Turnout Total (0-2)"

gen misreport04=repturn04-v2004g
gen misreport06=repturn06-v2006g
gen underreport04=(misreport04==-1)
gen underreport06=(misreport06==-1)
recode misreport04 misreport06 (-1=0)

gen misreport_total=misreport04+misreport06
gen underreport_total=underreport04+underreport06

label var misreport04 "Overreport Voting 2004 (1=yes)"
label var misreport06 "Overreport Voting 2006 (1=yes)"
label var misreport_total "Overreport Voting Total (0-2)"
label var underreport04 "Underreport Voting 2004 (1=yes)"
label var underreport06 "Underreport Voting 2006 (1=yes)"
label var underreport_total "Underreport Voting Total (0-2)"

*** RESTRICT SAMPLE TO OBSERVATIONS WITH VARIATION IN ALL COMPONENTS OF INDEXES/TURNOUT/ETC.

gen insample=1
replace insample=0 if age<26

qui foreach i in act_local_official act_local_meet act_local_meet_speak act_rally act_volunteer act_donate_cand {
 logit `i' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 
 replace insample=0 if e(sample)==0
}

qui foreach i in act_campaign act_local turntotal turnrecent {
 ologit `i' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1  
 replace insample=0 if e(sample)==0
}

outsum BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age income incomemis educ if insample==1 [aw=weight] using "tableA1_summarystats", bracket ctitle(CT Survey) append

corr BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness if insample==1 [aw=weight]


*** PARTICIPATION INDICES

**** NO EDUCATION/INCOME MODEL
ologit act_campaign BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 [pw=weight], r
sum act_campaign if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "table4_report_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

**** COUNT MODEL
nbreg act_campaign BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
sum act_campaign if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table4_report_countmodels.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

**** ALT OPENNESS MODEL
ologit act_campaign BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
sum act_campaign if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "table4_report_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

**** REPORTED MODEL
ologit act_campaign BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
sum act_campaign if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table4_report.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

*This is the marginal effects for the income/education specification
*Outcome is act_campaign being not 0
qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
 if "`varofinterest'"~="income" {
  summ `varofinterest' if e(sample) [aweight=weight]
 }
 else {
  *varofinterest=1 is to exclude income missing folks
  summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
 }
 local sd2=`r(sd)'*2
 prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
 matrix base=r(predval)
 matrix base=1-base[1,1]
 matrix mfx=r(change0)
 if "`varofinterest'"~="educC_5" {
  matrix submfx=-1*mfx[9,1]
 }
 else {
  matrix submfx=-1*mfx[6,1]
 }
 matrix submfx=-1*mfx[9,1]
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx=base
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
  else {
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
}

matrix list finalmfx
matrix active_mfx=finalmfx
**** NO INCOME/EDUC
ologit act_local BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 [pw=weight], r
sum act_local if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "table4_report_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

**** COUNT MODEL
nbreg act_local BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
sum act_local if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table4_report_countmodels.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

**** ALT OPENNESS MODEL
ologit act_local BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
sum act_local if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "table4_report_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

**** REPORTED MODEL
ologit act_local BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
sum act_local if insample==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table4_report.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append

*This is the marginal effects for the income/education specification
*Outcome is act_local being not 0
qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
 if "`varofinterest'"~="income" {
  summ `varofinterest' if e(sample) [aweight=weight]
 }
 else {
  *varofinterest=1 is to exclude income missing folks
  summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
 }
 local sd2=`r(sd)'*2
 prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
 matrix base=r(predval)
 matrix base=1-base[1,1]
 matrix mfx=r(change0)
 if "`varofinterest'"~="educC_5" {
  matrix submfx=-1*mfx[9,1]
 }
 else {
  matrix submfx=-1*mfx[6,1]
 }
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx=base
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
  else {
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
}

matrix list finalmfx
matrix active_mfx=active_mfx,finalmfx
svmat active_mfx, names(turnoutmfx)
outsheet turnoutmfx* using table4_report_mfx_2.csv,comma replace
drop turnoutmfx* 


***ACTIVE ITEMS
foreach v in act_donate_cand act_volunteer act_rally act_local_official act_local_meet act_local_meet_speak {
*** NO EDUCATION/INCOME 
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 [pw=weight], r
 sum `v' if insample==1 [aweight=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 if "`v'"=="act_donate_cand" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "active_items_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "active_items_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }

*** ALT OPENNESS MODEL
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 sum `v' if insample==1 [aweight=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
 if "`v'"=="act_donate_cand" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "active_items_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "active_items_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }
*** REPORTED MODEL
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 sum `v' if insample==1 [aweight=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 if "`v'"=="act_donate_cand" {
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "active_items.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster replace
 }
 else{
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "active_items.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 }

 *MFX for each variable here is probability of being in category 1
 *This is the marginal effects for the income/education specification
 qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
  if "`varofinterest'"~="income" {
   summ `varofinterest' if e(sample) [aweight=weight]
  }
  else {
   *varofinterest=1 is to exclude income missing folks
   summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
  }
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
  matrix base=r(predval)
  matrix base=base[1,2]
  matrix mfx=r(change)
  if "`varofinterest'"~="educC_5" {
   matrix submfx=mfx[9,1]
  }
  else {
   matrix submfx=mfx[6,1]
  }
  if "`varofinterest'"=="BF_extraversion" {
   matrix finalmfx=base
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
   else {
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
  }

 di "*************************"
 di "MFX DV=`v'"
 di "*************************"
 
 matrix list finalmfx
 if "`v'"=="act_donate_cand" {
 matrix active_itemsmfx=finalmfx
 }
 else{
 matrix active_itemsmfx=active_itemsmfx,finalmfx
 }
}

* WITHIN MEETING
***NO EDUC INCOME MODEL 
logit act_local_meet_speak BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 & act_local_meet==1 [pw=weight], r
sum act_local_meet_speak if e(sample)==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "active_items_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 

***ALT OPENNESS MODEL 
logit act_local_meet_speak BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 & act_local_meet==1 [pw=weight], r
sum act_local_meet_speak if e(sample)==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "active_items_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 

***REPORTED MODEL 
logit act_local_meet_speak BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 & act_local_meet==1 [pw=weight], r
sum act_local_meet_speak if e(sample)==1 [aweight=weight]
local n=r(mean)
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "active_items.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 

*MFX for each variable here is probability of being in category 1
*This is the marginal effects for the income/education specification
qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
 if "`varofinterest'"~="income" {
  summ `varofinterest' if e(sample) [aweight=weight]
 }
 else {
  *varofinterest=1 is to exclude income missing folks
  summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
 }
 local sd2=`r(sd)'*2
 prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
 matrix base=r(predval)
 matrix base=base[1,2]
 matrix mfx=r(change)
  if "`varofinterest'"~="educC_5" {
   matrix submfx=mfx[9,1]
  }
  else {
   matrix submfx=mfx[6,1]
  }
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx=base
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
  else {
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
 }

matrix list finalmfx
matrix active_itemsmfx=active_itemsmfx,finalmfx
svmat active_itemsmfx, names(turnoutmfx)
outsheet turnoutmfx* using active_itemsmfx.csv,comma replace
drop turnoutmfx* 


****** VALIDATED TURNOUT
**** NO INCOME/EDUC
ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 [pw=weight], r
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
local a=r(p)
sum turntotal if insample==1 [aw=weight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "table3_validTO_noeducinc.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster append 

**** COUNT MODEL
nbreg turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
local a=r(p)
sum turntotal if insample==1 [aw=weight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table3_validTO_countmodels.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster append 

**** ALT OPENNESS MODEL
ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
local a=r(p)
sum turntotal if insample==1 [aw=weight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "table3_validTO_alt.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster append 

**** REPORTED MODEL
ologit turntotal BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
local a=r(p)
sum turntotal if insample==1 [aw=weight]
outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table3_validTO.out", se addstat("F-test: Big Five", `a', "Mean", r(mean)) adec(3) bracket rdec(3) 3aster append 

*This is the marginal effects for the income/education specification
*Outcome is pas_total being 2, 3 or 4
foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
 if "`varofinterest'"~="income" {
  summ `varofinterest' if e(sample) [aweight=weight]
 }
 else {
  *varofinterest=1 is to exclude income missing folks
  summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
 }
 local sd2=`r(sd)'*2
 prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
 matrix base=r(predval)
 matrix base0=base[1,2]
 matrix base1=base[1,3]
 matrix base2=base[1,4]
 matrix base=base0+base1+base2
 if "`varofinterest'"~="educC_5" {
  matrix mfx=r(change2)
  matrix submfx0=mfx[9,1]
  matrix mfx=r(change3)
  matrix submfx1=mfx[9,1]
  matrix mfx=r(change4)
  matrix submfx2=mfx[9,1]
 }
 else {
  matrix mfx=r(change2)
  matrix submfx0=mfx[6,1]
  matrix mfx=r(change3)
  matrix submfx1=mfx[6,1]
  matrix mfx=r(change4)
  matrix submfx2=mfx[6,1]
 }
 matrix submfx=submfx0+submfx1+submfx2
 if "`varofinterest'"=="BF_extraversion" {
  matrix finalmfx=base
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
  else {
  matrix finalmfx=finalmfx\(submfx/base[1,1])
  }
}

matrix list finalmfx
matrix valid_turnoutmfx=finalmfx

*** REPORTED TURNOUT

foreach v in turnrecent repturn_total {
**** NO INCOME/EDUC
 ologit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 & repturn_total!=. [pw=weight], r
 sum `v' if insample==1  [aw=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
  outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "table3_validTO_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 

/*
**** COUNT MODEL
 nbreg `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table3_validTO_countmodels.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) 3aster append 
*/

**** ALT OPENNESS MODEL
 ologit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 & repturn_total!=.  [pw=weight], r
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "table3_validTO_alt.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) 3aster append 

**** REPORTED MODEL
 ologit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 & repturn_total!=. [pw=weight], r
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table3_validTO.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) 3aster append 

 *MFX for each variable here is probability of being in category 2 (real or reported turnout)
 *This is the marginal effects for the income/education specification
 *Outcome is act_campaign being not 0
 qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
  if "`varofinterest'"~="income" {
   summ `varofinterest' if e(sample) [aweight=weight]
  }
  else {
   *varofinterest=1 is to exclude income missing folks
   summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
  }
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
  matrix base=r(predval)
  matrix base=base[1,3]
  matrix mfx=r(change2)
  if "`varofinterest'"~="educC_5" {
   matrix submfx=mfx[9,1]
  }
  else {
   matrix submfx=mfx[6,1]
  }
  if "`varofinterest'"=="BF_extraversion" {
   matrix finalmfx=base
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
   else {
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
 }

 di "*************************"
 di "MFX DV=`v'"
 di "*************************"
 
matrix list finalmfx
matrix valid_turnoutmfx=valid_turnoutmfx,finalmfx
}

foreach v in misreport_total {

 ologit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 if insample==1 [pw=weight], r
 sum `v' if insample==1 [aw=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 using "table3_validTO_noeducinc.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 


**** COUNT MODEL
 nbreg `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table3_validTO_countmodels.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) 3aster append 

**** ALT OPENNESS MODEL
 ologit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "table3_validTO_alt.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) 3aster append 

**** REPORTED MODEL
 ologit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "table3_validTO.out", se addstat("F-test: Big Five", r(p)) adec(3) bracket rdec(3) 3aster append 

 *MFX for each variable here is probability of not being in category 0 (overreport)
 *This is the marginal effects for the income/education specification
 *Outcome is act_campaign being not 0
 qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
  if "`varofinterest'"~="income" {
   summ `varofinterest' if e(sample) [aweight=weight]
  }
  else {
   *varofinterest=1 is to exclude income missing folks
   summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
  }
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
  matrix base=r(predval)
  matrix base=1-base[1,1]
  matrix mfx=r(change0)
  if "`varofinterest'"~="educC_5" {
   matrix submfx=-1*mfx[9,1]
  }
  else {
   matrix submfx=-1*mfx[6,1]
  }
  if "`varofinterest'"=="BF_extraversion" {
   matrix finalmfx=base
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
   else {
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
 }
  
 matrix list finalmfx
 matrix valid_turnoutmfx=valid_turnoutmfx,finalmfx
}
svmat valid_turnoutmfx, names(turnoutmfx)
outsheet turnoutmfx* using table3B_validTO_mfx_2.csv,comma replace
drop turnoutmfx* 


foreach v in v2000g v2002g v2004 v2006g{
*** ALT OPENNESS MODEL
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 sum `v' if insample==1 [aw=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness_alt r_nwhite age age2 income incomemis educC_* using "byelection_alt.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 

*** REPORTED MODEL
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if insample==1 [pw=weight], r
 sum `v' if insample==1 [aw=weight]
 local n=r(mean)
 test BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness 
 outreg BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* using "byelection.out", se addstat("F-test: Big Five", r(p), "Mean", `n') adec(3) bracket rdec(3) 3aster append 
 *MFX for each variable here is probability of being in category 1
 *This is the marginal effects for the income/education specification
 logit `v' BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness r_nwhite age age2 income incomemis educC_* if e(sample)==1 [pw=weight], r
 qui foreach varofinterest in BF_extraversion BF_agreeable BF_conscientious BF_stability BF_openness income educC_5 {
  if "`varofinterest'"~="income" {
   summ `varofinterest' if e(sample) [aweight=weight]
  }
  else {
   *varofinterest=1 is to exclude income missing folks
   summ `varofinterest' if e(sample) & `varofinterest'~=1  [aweight=weight]
  }
  local sd2=`r(sd)'*2
  prchange `varofinterest', x(age=62 age2=38.44 income=.50 BF_extraversion=.61 BF_agreeableness=.80 BF_conscientiousness=.86 BF_stability=.76 BF_openness=.72) rest(min) fromto delta(`sd2')
  matrix base=r(predval)
  matrix base=base[1,2]
  matrix mfx=r(change)
  if "`varofinterest'"~="educC_5" {
   matrix submfx=mfx[9,1]
  }
  else {
   matrix submfx=mfx[6,1]
  }
  if "`varofinterest'"=="BF_extraversion" {
   matrix finalmfx=base
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
   else {
   matrix finalmfx=finalmfx\(submfx/base[1,1])
   }
  }
 matrix list finalmfx
 if "`v'"=="v2000g" {
 matrix by_election_mfx=finalmfx
 }
 else{
 matrix by_election_mfx=by_election_mfx,finalmfx
 }
}

svmat by_election_mfx, names(turnoutmfx)
outsheet turnoutmfx* using by_election_mfx2.csv,comma replace
drop turnoutmfx* 
